Package: competitiontoolbox
Type: Package
Title: A Graphical User Interface for Antitrust and Trade Practitioners
Version: 0.7.1
Authors@R: c(person("Charles", "Taragin", email = "ctaragin+competitiontoolbox@gmail.com",
                  role = c("aut", "cre")),
             person("Kenneth", "Rios", email = "krios@ftc.gov",
                  role = c("aut")),
             person("Paulette", "Wolak", email = "",
                  role = c("aut"))     
                  )
Depends: R (>= 2.10), antitrust (>= 0.99.11), trade (>= 0.5.4), shiny,
        rhandsontable
Imports: ggplot2
Description: A graphical user interface for simulating the effects of mergers, tariffs, and quotas under an
             assortment of different economic models. The interface is powered by the 'Shiny' web application framework from 
             'RStudio'.
URL: https://github.com/luciu5/competitiontoolbox
License: CC0
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.1
NeedsCompilation: no
Packaged: 2022-08-24 20:51:45 UTC; ctara
Author: Charles Taragin [aut, cre],
  Kenneth Rios [aut],
  Paulette Wolak [aut]
Maintainer: Charles Taragin <ctaragin+competitiontoolbox@gmail.com>
Repository: CRAN
Date/Publication: 2022-08-25 08:22:47 UTC
Built: R 4.6.0; ; 2026-04-26 17:13:44 UTC; unix
